@@ -675,6 +675,9 @@ class OmniLogic:
         backyard_name = ""
         BOWname = ""
 
+        if site_alarms[0].get("BowID") == "False":
+            site_alarms = []
+
         for child in telemetryXML:
             if "version" in child.attrib:
                 continue
@@ -882,7 +885,7 @@ class OmniLogic:
                 this_csad["Alarms"] = []
 
                 for alarm in site_alarms:
-                    if bow_item["System-Id"] == alarm["BowID"] and this_csad["systemId"] == alarm["EquipmentID"]:
+                    if this_csad["systemId"] == alarm["EquipmentID"]:
                         this_csad["Alarms"].append(alarm)
                 
                 BOW[child.tag] = this_csad
@@ -937,11 +940,13 @@ class OmniLogic:
                     "MspSystemID": system["MspSystemID"],
                     "Version": "0",
                 }
-                site_alarms = []
 
                 this_alarm = await self.call_api("GetAlarmList", params)
 
-                site_alarms.append(self.alarms_to_json(this_alarm))
+                site_alarms = self.alarms_to_json(this_alarm)
+
+                if site_alarms[0].get("BowID") == "False":
+                    site_alarms = []
                 
                 site_telem = self.telemetry_to_json(telem, config_item, self.alarms_to_json(this_alarm))
 
@@ -956,6 +961,7 @@ class OmniLogic:
                 ]
                 site_telem["Msp-Language"] = config_item["System"]["Msp-Language"]
                 site_telem["Unit-of-Measurement"] = config_item["System"]["Units"]
+                site_telem["Alarms"] = site_alarms
 
                 if type(config_item["Backyard"]["Sensor"]) == dict:
                   site_telem["Unit-of-Temperature"] = config_item["Backyard"]["Sensor"][
